@@ -1,12 +1,22 @@
 class Location:
- def __init__(self, file, current_element, line, column, line_end, column_end):
+ def __init__(self, file, current_element, ce_line, ce_column, ce_line_end, ce_column_end, line, column, line_end, column_end):
                 self.file = file
                 self.current_element = current_element
+                self.current_element_line = ce_line
+                self.current_element_column = ce_column
+                self.current_element_line_end = ce_line_end
+                self.current_element_column_end = ce_column_end
                 self.line = line
                 self.column = column
                 self.line_end = line_end
                 self.column_end = column_end
 
+class Comment:
+ def __init__(self, comment_before, comment_middle, comment_after):
+                self.before = comment_before
+                self.middle = comment_middle
+                self.after = comment_after
+
 class ElemBase:
         def __init__(self):
                 pass
